@@ -2,14 +2,16 @@
 function(patterns,freq,nclass,calcSE,notrials,probit,penalty,verbose) {
 	bics <- rep(NA,notrials)
 	for (i in 1:notrials) {
-		lca <- fit.fixed.randomLCA(patterns,freq,nclass=nclass,calcSE=FALSE,probit=probit,penalty=penalty,verbose=verbose)
+		lca <- fitFixed(patterns,freq,nclass=nclass,calcSE=FALSE,justEM=TRUE,probit=probit,penalty=penalty,verbose=verbose)
 		#browser()
 		currbic <- -2*(lca$logLik)+log(lca$nobs)*lca$np
 		bics[i] <- currbic
+		#browser()
 		if (i==1) {
 			maxbic <- currbic
 			maxlca <- lca
 		}
+		#print(c(currbic,maxbic))
 		if (currbic < maxbic) {
 			maxbic <- currbic
 			maxlca <- lca
@@ -17,13 +19,10 @@ function(patterns,freq,nclass,calcSE,notrials,probit,penalty,verbose) {
 		if (verbose)
 			cat("iteration ",i,"BIC ",BIC(lca),"\n")
 	}
-	if (calcSE) {
 		if (verbose) print("refitting to obtain SE")
-		maxlca <- fit.fixed.randomLCA(patterns,freq,nclass=nclass,initoutcomep=maxlca$outcomep,
-			initclassp=maxlca$classp,calcSE=TRUE,probit=probit,penalty=penalty,verbose=verbose)
-	}
+		maxlca <- fitFixed(patterns,freq,nclass=nclass,initoutcomep=maxlca$outcomep,
+			initclassp=maxlca$classp,calcSE=calcSE,justEM=FALSE,probit=probit,penalty=penalty,verbose=verbose)
 	if (verbose) {
-		print(maxlca)
 		print("bic for class")
 		print(bics)
 	}
